# bioleach-balrog

An alternate version of [bioleach](https://pypi.org/project/bioleach/) that uses the machine-learning based method [balrog](https://github.com/salzberg-lab/BalrogCPP) for gene prediction

## installation

```sh
conda create -n bioleach -c conda-forge -c bioconda \
  pandas seaborn biopython sra-tools pysradb \
  mysql-connector-python sqlalchemy fastp kraken2 bowtie2 \
  megahit prodigal numpy=2.3 pytorch mmseqs2 balrog
pip install bioleach-balrog
```
